@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2010-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -43,10 +43,27 @@ class Wicked_Application extends Horde_Registry_Application
 {
     /**
      */
-    public $version = 'H5 (2.0.7)';
+    public $version = 'H5 (2.0.8)';
 
     protected function _bootstrap()
     {
+        set_include_path(
+            __DIR__ . DIRECTORY_SEPARATOR . 'Text_Wiki'
+            . PATH_SEPARATOR . get_include_path()
+        );
+        $autoloader = $GLOBALS['injector']->getInstance('Horde_Autoloader');
+        $autoloader->addClassPathMapper(
+            new Horde_Autoloader_ClassPathMapper_Prefix(
+                '/^Text_Wiki/',
+                WICKED_BASE . '/lib/Text_Wiki/Text/Wiki'
+            )
+        );
+        $autoloader->addClassPathMapper(
+            new Horde_Autoloader_ClassPathMapper_Prefix(
+                '/^Text_Wiki$/',
+                WICKED_BASE . '/lib/Text_Wiki/Text/Wiki.php'
+            )
+        );
         $GLOBALS['injector']->bindFactory('Wicked_Driver', 'Wicked_Factory_Driver', 'create');
     }
 
@@ -132,10 +149,14 @@ class Wicked_Application extends Horde_Registry_Application
     {
         global $wicked;
 
-        $page = $vars->get('page', 'Wiki/Home');
+        $pageName = $vars->get('page', 'Wiki/Home');
+        $page = Wicked_Page::getPage($pageName);
+        if (!$page->allows(Wicked::MODE_DISPLAY)) {
+            throw new Horde_Exception_PermissionDenied();
+        }
 
-        $page_id = (($id = $wicked->getPageId($page)) === false)
-            ? $page
+        $page_id = (($id = $wicked->getPageId($pageName)) === false)
+            ? $pageName
             : $id;
 
         $version = $vars->version;
