@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2003-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -72,6 +72,8 @@ class Wicked_Page
      * permissions object does not exist, we assume reasonable
      * defaults.
      *
+     * @param  string $pageName  The page name.
+     *
      * @return integer  The permissions bitmask.
      */
     public function getPermissions($pageName = null)
@@ -530,20 +532,6 @@ class Wicked_Page
             break;
         }
 
-        $autoloader = $GLOBALS['injector']->getInstance('Horde_Autoloader');
-        $autoloader->addClassPathMapper(
-            new Horde_Autoloader_ClassPathMapper_Prefix(
-                '/^Text_Wiki_Render_' . $output_format . '/',
-                WICKED_BASE . '/lib/Text_Wiki/Render/' . $output_format
-            )
-        );
-        $autoloader->addClassPathMapper(
-            new Horde_Autoloader_ClassPathMapper_Prefix(
-                '/^Text_Wiki_Parse/',
-                WICKED_BASE . '/lib/Text_Wiki/Parse/' . $GLOBALS['conf']['wicked']['format']
-            )
-        );
-
         return $this->_proc;
     }
 
