@@ -4,7 +4,7 @@
  *
  * PHP version 5
  *
- * Copyright 2011-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPLv2). If
  * you did not receive this file, see
@@ -19,7 +19,7 @@
  */
 
 Horde_Test_Autoload::addPrefix('Wicked', __DIR__ . '/../../lib');
-Horde_Test_Autoload::addPrefix('Text/Wiki/Render/Rst', __DIR__ . '/../../lib/Text_Wiki/Render/Rst');
+Horde_Test_Autoload::addPrefix('Text_Wiki', __DIR__ . '/../../lib/Text_Wiki');
 
 /** Load the basic test definition */
 require_once __DIR__ . '/TestCase.php';
